@@ -8,6 +8,7 @@ these are not really related, formatting could be factored out as
 a separate base
 """
 
+import sys
 import copy
 
 from collections import MutableSet, Sized, Set
@@ -177,6 +178,7 @@ class Tag(object):
         self.value = None
 
     def __repr__(self):
+        # type: () -> Any
         return '{0.__class__.__name__}({0.value!r})'.format(self)
 
 
@@ -849,14 +851,14 @@ class CommentedMap(ordereddict, CommentedBase):
             yield x, ordereddict.__getitem__(self, x)
         done = []  # type: List[Any]  # list of processed merge items, kept for masking
         for merged in getattr(self, merge_attrib, []):
-            for x in merged[1]:
+            for x, v in merged[1].items():
                 if ordereddict.__contains__(self, x):
                     continue
                 for y in done:
                     if x in y:
                         break
                 else:
-                    yield x, ordereddict.__getitem__(merged[1], x)
+                    yield x, v  # ordereddict.__getitem__(merged[1], x)
             done.append(merged[1])
 
     if PY2:
@@ -937,3 +939,24 @@ class CommentedSet(MutableSet, CommentedMap):
     def __repr__(self):
         # type: () -> str
         return 'set({0!r})'.format(self.odict.keys())
+
+
+def dump_comments(d, name='', sep='.', out=sys.stdout):
+    # type: (Any, str, str, Any) -> None
+    """
+    recurisively dump domments all but the toplevel preceded by the path
+    in dotted form x.0.a
+    """
+    if isinstance(d, dict):
+        if name:
+            print(name)
+        print(d.ca, file=out)  # type: ignore
+        for k in d:
+            dump_comments(d[k], name=(name + sep + k) if name else k, sep=sep, out=out)
+    elif isinstance(d, list):
+        if name:
+            print(name)
+        print(d.ca, file=out)  # type: ignore
+        for idx, k in enumerate(d):
+            dump_comments(k, name=(name + sep + str(idx)) if name else str(idx),
+                          sep=sep, out=out)
